package com.vp.plugin.sample.griddiagram.actions;

import com.vp.plugin.ApplicationManager;
import com.vp.plugin.DiagramManager;
import com.vp.plugin.action.VPAction;
import com.vp.plugin.action.VPActionController;
import com.vp.plugin.diagram.IDiagramTypeConstants;
import com.vp.plugin.diagram.IGridDiagramUIModel;
import com.vp.plugin.model.IGridDiagramColumn;
import com.vp.plugin.model.IGridDiagramColumnContainer;
import com.vp.plugin.model.IModelElement;
import com.vp.plugin.model.IProject;
import com.vp.plugin.model.IUseCase;
import com.vp.plugin.model.factory.IModelElementFactory;

public class GridDiagramActionControl implements VPActionController {

	@Override
	public void performAction(VPAction arg0) {
		// Create couple of sample use cases and with different ranks
		IUseCase uc1 = IModelElementFactory.instance().createUseCase();
		uc1.setName("uc1");
		uc1.setUcRank(IUseCase.UC_RANK_MEDIUM);
		
		IUseCase uc2 = IModelElementFactory.instance().createUseCase();
		uc2.setName("uc2");
		uc2.setUcRank(IUseCase.UC_RANK_LOW);

		IUseCase uc3 = IModelElementFactory.instance().createUseCase();
		uc3.setName("uc3");
		uc3.setUcRank(IUseCase.UC_RANK_HIGH);
		
		// Obtain DiagramManager form ApplicationManager 
		DiagramManager diagramManager = ApplicationManager.instance().getDiagramManager();
		
		// Create a new Grid Diagram
		IGridDiagramUIModel gridDiagram = (IGridDiagramUIModel) diagramManager.createDiagram(IDiagramTypeConstants.DIAGRAM_TYPE_GRID_DIAGRAM);
		// Specify the Grid Diagram for showing use case model
		gridDiagram.setModelTypes(new String[] {IModelElementFactory.MODEL_TYPE_USE_CASE});
		
		// Locate/Create IGridDiagramColumnContainer for storing the columns
		IGridDiagramColumnContainer colContainer = null;		
		
		// Obtain reference to our opening project
		IProject project = ApplicationManager.instance().getProjectManager().getProject();
		// Try to load the IGridDiagramColumnContainer from project
		// if the resulting collection is not empty then we assume the IGridDiagramColumnContainer
		// was found and we can reuse it. Otherwise we just create a new one 
		IModelElement[] containers = project.toAllLevelModelElementArray(IModelElementFactory.MODEL_TYPE_GRID_DIAGRAM_COLUMN_CONTAINER);
		if (containers != null && containers.length > 0) {
			colContainer = (IGridDiagramColumnContainer) containers[0];
		} else {
			colContainer = IModelElementFactory.instance().createGridDiagramColumnContainer();
		}
		
		// Create column from IGridDiagramColumnContainer
		IGridDiagramColumn colName = colContainer.createGridDiagramColumn();
		// Specify the property for the column to present in grid   
		colName.setColumnValue(IGridDiagramColumn.PROP_NAME);
		
		IGridDiagramColumn colAuthor = colContainer.createGridDiagramColumn();
		colAuthor.setColumnValue(IGridDiagramColumn.PROP_PM_AUTHOR);

		IGridDiagramColumn colRank = colContainer.createGridDiagramColumn();
		colRank.setColumnValue(IUseCase.PROP_UC_RANK);
		
		// Set the columns you would like to show into the grid
		gridDiagram.setColumns(colContainer.toGridDiagramColumnArray());
		
		// Show up Grid Diagram in UI
		diagramManager.openDiagram(gridDiagram);				

	}

	@Override
	public void update(VPAction arg0) {
		// TODO Auto-generated method stub
		
	}

}
